@@ -70,7 +70,7 @@ private:
     pa_cvolume m_volume;
     pa_channel_map m_channelMap;
     QStringList m_channels;
-    bool m_muted;
+    bool m_muted = false;
 
     struct {
         bool valid = false;
